import os
import re
from pathlib import Path
from typing import List, Dict, Tuple

from dotenv import load_dotenv
from fastmcp import FastMCP
from fastmcp.exceptions import ToolError
from fastmcp.server.dependencies import get_http_headers

from imagenx import factory, operator, utils


load_dotenv()

mcp = FastMCP(
    name='imagenx-mcp-server',
    instructions='图片视频生成工具，按照用户需求生成图片或视频',
)


@mcp.tool
def analyze_query(plan: str, tool_chains: List[str]) -> Dict[str, str]:
    '''分析用户需求，制定计划。确保用户输入query时首先调用此工具。

    Args:
        plan (str): 工具调用的思考和计划
        tool_chains (List[str]): 工具链列表: text_to_image | image_to_image | image_inspect | text_to_video | image_to_video ...
        
    Returns:
        工具参数更详细的说明
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    result = {}

    for tool in tool_chains:
        tool = tool.strip()

        if tool == 'text_to_image':
            model, api_key = utils.get_provider_model_api_key(tool, headers, env)
            generator = factory.create_text_to_image(model, api_key)
            result[tool] = re.sub(r' +', ' ', generator.text_to_image.__doc__)
        elif tool == 'image_to_image':
            model, api_key = utils.get_provider_model_api_key(tool, headers, env)
            generator = factory.create_image_to_image(model, api_key)
            result[tool] = re.sub(r' +', ' ', generator.image_to_image.__doc__)
        elif tool == 'text_to_video':
            model, api_key = utils.get_provider_model_api_key(tool, headers, env)
            generator = factory.create_text_to_video(model, api_key)
            result[tool] = re.sub(r' +', ' ', generator.text_to_video.__doc__)
        elif tool == 'image_to_video':
            model, api_key = utils.get_provider_model_api_key(tool, headers, env)
            generator = factory.create_image_to_video(model, api_key)
            result[tool] = re.sub(r' +', ' ', generator.image_to_video.__doc__)
        else:
            pass

    return result


@mcp.tool
def text_to_image(prompt: str, size: str) -> List:
    '''根据输入的提示词生成图片.
    确保用户需要文生图时先调用`analyze_query`工具，再调用此工具。
    确保用Markdown格式输出图片url，例如：[title](url)
    确保生成图片后用`download`工具下载到本地，如果没有`download`工具，用命令行`curl`命令下载
        
    Args:
        prompt (str): 生成图片的提示词
        size (str): 生成图像的分辨率或宽高像素值
        
    Returns:
        生成的图片url。
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    model, api_key = utils.get_provider_model_api_key('text_to_image', headers, env)

    if model is None:
        raise ToolError('IMAGENX_TEXT_TO_IMAGE is None')

    if api_key is None:
        raise ToolError(f'IMAGENX_{model.split(":")[0].upper()}_API_KEY is None')

    try:
        generator = factory.create_text_to_image(model, api_key)
        url_list = generator.text_to_image(prompt, size)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return url_list


@mcp.tool
def image_to_image(prompt: str, images: List[str], size: str) -> List:
    '''根据输入的提示词和图片生成新图片。
    确保用户需要图生图时先调用`analyze_query`工具，再调用此工具。
    确保用Markdown格式输出图片url，例如：[title](url)
    确保生成图片后用`download`工具下载到本地，如果没有`download`工具，用命令行`curl`命令下载
        
    Args:
        prompt (str): 生成图片的提示词
        images (List[str]): 输入图片url列表或文件路径列表
        size (str): 生成图像的分辨率或宽高像素值
        
    Returns:
        生成的图片url。
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    model, api_key = utils.get_provider_model_api_key('image_to_image', headers, env)

    if model is None:
        raise ToolError('IMAGENX_IMAGE_TO_IMAGE is None')

    if api_key is None:
        raise ToolError(f'IMAGENX_{model.split(":")[0].upper()}_API_KEY is None')

    try:
        generator = factory.create_image_to_image(model, api_key)
        url_list = generator.image_to_image(prompt, images, size)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return url_list


@mcp.tool
def text_to_video(prompt: str, resolution: str, ratio: str, duration: int) -> str:
    '''根据输入的提示词生成视频。
    确保用户需要文生视频时先调用`analyze_query`工具，再调用此工具。
    确保用Markdown格式输出视频url，例如：[title](url)
    确保生成视频后用`download`工具下载到本地，如果没有`download`工具，用命令行`curl`命令下载
        
    Args:
        prompt (str): 生成图片的提示词
        resolution (str): 生成视频的分辨率
        ratio (str): 生成视频的比例
        duration (int): 生成视频的时长
        
    Returns:
        视频下载的url
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    model, api_key = utils.get_provider_model_api_key('text_to_video', headers, env)

    if model is None:
        raise ToolError('IMAGENX_TEXT_TO_VIDEO is None')

    if api_key is None:
        raise ToolError(f'IMAGENX_{model.split(":")[0].upper()}_API_KEY is None')

    try:
        generator = factory.create_text_to_video(model, api_key)
        url = generator.text_to_video(prompt, resolution, ratio, duration)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return url


@mcp.tool
def image_to_video(prompt: str, resolution: str, ratio: str, duration: int, 
                   first_frame: str, last_frame: str|None = None) -> str:
    '''根据输入的提示词和视频首尾帧图片生成视频。
    确保用户需要图生视频时先调用`analyze_query`工具，再调用此工具。
    确保用Markdown格式输出视频url，例如：[title](url)
    确保生成视频后用`download`工具下载到本地，如果没有`download`工具，用命令行`curl`命令下载
        
    Args:
        prompt (str): 生成图片的提示词
        resolution (str): 生成视频的分辨率
        ratio (str): 生成视频的比例
        duration (int): 生成视频的时长
        first_frame (str): 视频的首帧图片url或文件路径
        last_frame (str|None): 视频的尾图片url或文件路径，默认None
        
    Returns:
        视频下载的url
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    model, api_key = utils.get_provider_model_api_key('image_to_video', headers, env)

    if model is None:
        raise ToolError('IMAGENX_IMAGE_TO_VIDEO is None')

    if api_key is None:
        raise ToolError(f'IMAGENX_{model.split(":")[0].upper()}_API_KEY is None')

    try:
        generator = factory.create_image_to_video(model, api_key)
        url = generator.image_to_video(prompt, first_frame, last_frame, resolution, ratio, duration)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return url


@mcp.tool
def inspect_image(prompt: str, image: str) -> str:
    '''观察分析图片获取精确的信息，确保用户需要分析，编辑、裁剪图片时先调用此工具。
    确保尽量用精确数字描述图片信息。
    输出图片裁剪区域时，确保给出精确的**小数比例坐标**，坐标为左上角和右下角：x1(left), y1(upper), x2(right), y2(lower)

    Args:
        prompt (str): 分析图片的提示词
        image (str): 图片路径或URL

    Returns:
        str: 图片分析结果
    '''
    headers = get_http_headers(include_all=True)
    env = os.environ
    model, api_key = utils.get_provider_model_api_key('inspect_image', headers, env)

    if model is None:
        raise ToolError('IMAGENX_INSPECT_IMAGE is None')

    if api_key is None:
        raise ToolError(f'IMAGENX_{model.split(":")[0].upper()}_API_KEY is None')

    try:
        info = operator.get_image_info(image)
        prompt = f'image info: {info}\n\n{prompt}'

        inspector = factory.create_image_inspector(model, api_key)
        result = inspector.inspect(prompt, image)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return result


@mcp.tool
def download(url: str, path: str) -> str:
    '''读取生成的图片或视频 url 并保存到本地
    
    Args:
        url (str): 图片或视频 url
        path (str): 保存路径
    
    Returns:
        str: 成功时返回 'success'
    '''
    try:
        operator.download(url, path)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return 'success'


@mcp.tool
def get_image_info(image: str) -> Dict[str, str]:
    '''获取图片分辨率和类型信息，确保用户需要获取图片分辨率和类型信息时调用此工具。

    Args:
        image (str): 图片路径或URL

    Returns:
        Dict[str,str]: 分辨率和类型信息
    '''
    try:
        info = operator.get_image_info(image)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    return info


@mcp.tool
def crop_image(image: str, box: str, output: str) -> Dict[str, str]:
    '''框裁剪图片，确保用户需要裁剪图片时调用此工具。
    Args:
        image (str): 图片路径或URL
        box (str): 小数比例坐标，x1(left), y1(upper), x2(right), y2(lower)
        output (str): 输出文件路径（后缀决定格式）

    Returns:
        Dict[str,str]: 生成图片的 path
    '''
    try:
        operator.crop_image(image, box, output)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    p = Path(output).resolve()
    return {'title': p.name, 'path': str(p)}


@mcp.tool
def resize_image(image: str, size: str, output: str, keep_aspect: bool = True) -> Dict[str, str]:
    '''调整图片尺寸，确保用户需要调整图片尺寸时调用此工具。

    Args:
        image (str): 图片路径或URL
        size (str): "WIDTHxHEIGHT"
        output (str): 输出文件路径
        keep_aspect (bool): 是否保持比例（True 为等比不超过目标尺寸）

    Returns:
        Dict[str,str]: 生成图片的 path
    '''
    try:
        operator.resize_image(image, size, output, keep_aspect=keep_aspect)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    p = Path(output).resolve()
    return {'title': p.name, 'path': str(p)}


@mcp.tool
def convert_image(image: str, format: str, output: str, quality: int = 90) -> Dict[str, str]:
    '''格式转换，确保用户需要转换图片格式时调用此工具。

    Args:
        image (str): 图片路径或URL
        format (str): 目标格式：PNG/JPEG/JPG/WEBP
        output (str): 输出文件路径
        quality (int): 压缩质量（针对有损格式）

    Returns:
        Dict[str,str]: 生成图片的 path
    '''
    try:
        operator.convert_image(image, format, output, quality=quality)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    p = Path(output).resolve()
    return {'title': p.name, 'path': str(p)}


@mcp.tool
def adjust_image(image: str, output: str, brightness: float = 1.0, contrast: float = 1.0, saturation: float = 1.0) -> Dict[str, str]:
    '''基础图像调整：亮度/对比度/饱和度，确保用户需要调整图片时调用此工具。

    Args:
        image (str): 图片路径或URL
        output (str): 输出文件路径
        brightness (float): 亮度，默认1.0
        contrast (float): 对比度，默认1.0
        saturation (float): 饱和度，默认1.0

    Returns:
        Dict[str,str]: 生成图片的 path
    '''
    try:
        operator.adjust_image(image, output, brightness=brightness, contrast=contrast, saturation=saturation)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    p = Path(output).resolve()
    return {'title': p.name, 'path': str(p)}


@mcp.tool
def paste_image(front_image: str, background_image: str, output: str, position: Tuple[int, int]) -> Dict[str, str]:
    '''将图片粘贴到背景图片上，确保用户需要粘贴图片时调用此工具。
    粘贴图片前，需要用`resize_image`工具调整`front_image`到适合的尺寸。
    调用`analyze_image`工具确定粘贴位置。

    Args:
        front_image (str): 图片路径或URL
        background_image (str): 背景图片路径或URL
        output (str): 输出文件路径
        position (Tuple[int, int]): 粘贴位置的(x, y)，背景图片的左上角像素坐标

    Returns:
        Dict[str,str]: 生成图片的 path
    '''
    try:
        operator.paste_image(front_image, background_image, position, output)
    except Exception as e:
        raise ToolError(f'Error: {e}')

    p = Path(output).resolve()
    return {'title': p.name, 'path': str(p)}


@mcp.custom_route('/health', methods=['GET'])
def health() -> str:
    return 'success'


@mcp.custom_route('/healthy', methods=['GET'])
def healthy() -> str:
    return 'success'



from argparse import ArgumentParser


def get_version():
    return '1.0.4'


def run():
    parser = ArgumentParser()
    parser.add_argument('-v', '--version', action='version', version=get_version(), help='Show version number')
    subparsers = parser.add_subparsers(dest='command', required=True)

    server_parser = subparsers.add_parser('server', help='Start MCP server')
    server_parser.add_argument('--transport', default='stdio', help='Transport type: stdio, sse, or streamable-http')
    server_parser.add_argument('--host', default='0.0.0.0', help='Host address')
    server_parser.add_argument('--port', default=8000, type=int, help='Port number')
    server_parser.add_argument('--disable_tools', nargs='+', default=None, help='List of disabled tool names (space-separated)')

    image_parser = subparsers.add_parser('image', help='Generate image')
    image_parser.add_argument('prompt', help='Prompt for image generation')
    image_parser.add_argument('--images', nargs='+', default=None, help='Input image path list')
    image_parser.add_argument('--size', default=None, help='Image resolution or pixel dimensions.')
    image_parser.add_argument('--output', default='imagenx.jpg', help='Output file or directory path')

    video_parser = subparsers.add_parser('video', help='Generate video')
    video_parser.add_argument('prompt', help='Prompt for video generation')
    video_parser.add_argument('--first_frame', default=None, help='Path to the first frame of input video')
    video_parser.add_argument('--last_frame', default=None, help='Path to the last frame of input video')
    video_parser.add_argument('--resolution', default='720p', help='Video resolution. Options: 480p, 720p, 1080p')
    video_parser.add_argument('--ratio', default='16:9', help='Video aspect ratio. Options: 16:9, 4:3, 1:1, 3:4, 9:16, 21:9')
    video_parser.add_argument('--duration', default=5, type=int, help='Video duration in seconds')
    video_parser.add_argument('--output', default='imagenx.mp4', help='Output file path')

    args = parser.parse_args()

    if args.command == 'server':
        from imagenx.server import mcp

        if args.disable_tools:
            for tool in args.disable_tools:
                mcp.remove_tool(tool)

        if args.transport == 'stdio':
            mcp.run(transport='stdio')
        else:
            mcp.run(transport=args.transport, host=args.host, port=args.port)
    elif args.command == 'image':
        from imagenx import script
        script.gen_image(prompt=args.prompt, size=args.size, output=args.output, images=args.images)
    elif args.command == 'video':
        from imagenx import script
        script.gen_video(prompt=args.prompt, first_frame=args.first_frame, last_frame=args.last_frame,
                   resolution=args.resolution, ratio=args.ratio, duration=args.duration, output=args.output)
    else:
        raise ValueError(f'Unknown command: {args.command}')


if __name__ == '__main__':
    run()


from typing import List, Dict
from volcenginesdkarkruntime import Ark

from imagenx.predictor.base.base_text_to_image import BaseTextToImage


class DoubaoTextToImage(BaseTextToImage):

    def __init__(self, model: str, api_key: str):
        self.model = model
        self.client = Ark(
            base_url='https://ark.cn-beijing.volces.com/api/v3',
            api_key=api_key,
        )

    def text_to_image(self, prompt: str, size: str = '2048x2048') -> List[Dict[str, str]]:
        '''根据提示词生成图片。

        Args:
            prompt (str): 生成图片的提示词
            size (str): 生成图像的分辨率或宽高像素值
                    分辨率可选值：'1K'、'2K', '4K'
                    宽高像素可选值：2048x2048、2304x1728、1728x2304、2560x1440、1440x2560、2496x1664、1664x2496、3024x1296
        
        Returns:
            List[Dict[str: str]]: 图片url列表。
        '''
        response = self.client.images.generate(
            model=self.model,
            prompt=prompt,
            sequential_image_generation='auto',
            response_format='url',
            size=size.replace('*', 'x'),
            stream=False,
            watermark=False
        )

        result = []
        for item in response.model_dump()['data']:
            if 'b64_json' in item:
                item.pop('b64_json')
            result.append(item)

        return result


import base64
from pathlib import Path
import dashscope

from imagenx.predictor.base.base_image_to_video import BaseImageToVideo


class AliyunImageToVideo(BaseImageToVideo):

    def __init__(self, model: str, api_key: str):
        self.model = model
        self.api_key = api_key

    def image_to_video(self, prompt: str, first_frame: str, last_frame: str|None, 
                       resolution: str, ratio: str, duration: int) -> str:                       
        '''根据提示词和图片生成视频

        Args:
            prompt (str): 视频描述提示词
            first_frame (str): 视频第一帧图片url或文件路径
            last_frame (str|None): 视频最后一帧图片url或文件路径，可选
            resolution (str): 视频分辨率, 480P, 720P, 1080P
            ratio (str): 视频比例
            duration (int): 视频时长，单位秒, 5s, 10s
        
        Returns:
            视频url
        '''

        if not first_frame.startswith('http'):
            first_frame = self._image_to_base64(first_frame)

        if last_frame and not last_frame.startswith('http'):
            last_frame = self._image_to_base64(last_frame)

        response = dashscope.VideoSynthesis.call(
            model=self.model,
            api_key=self.api_key,
            prompt=prompt,
            img_url=first_frame,
            first_frame_url=first_frame,
            last_frame_url=last_frame,
            resolution=resolution.upper(),
            duration=duration,
            watermark=False,
        )
        return response.output.video_url

    def _image_to_base64(self, image_path: str) -> str:
        image_path = Path(image_path)

        with open(image_path, 'rb') as image_file:
            base64_image = base64.b64encode(image_file.read()).decode('utf-8')
            base64_image = f'data:image/{image_path.suffix.strip(".")};base64,{base64_image}'

        return base64_image


import time
from volcenginesdkarkruntime import Ark

from imagenx.predictor.base.base_text_to_video import BaseTextToVideo


class DoubaoTextToVideo(BaseTextToVideo):

    def __init__(self, model: str, api_key: str):
        self.model = model
        self.client = Ark(
            base_url='https://ark.cn-beijing.volces.com/api/v3',
            api_key=api_key,
        )

    def text_to_video(self, prompt: str, resolution: str = '720p', ratio: str = '16:9', duration: int = 5) -> str:
        '''根据提示词生成视频。

        Args:
            prompt (str): 生成视频的提示词
            resolution (str): 生成视频的分辨率：480p、720、1080p
            ratio (str): 生成视频的比例：16:9、4:3、1:1、3:4、9:16、21:9
            duration (int): 生成视频的时长，单位秒，支持 2~12 秒
        
        Returns:
            视频下载的url
        '''
        create_result = self.client.content_generation.tasks.create(
            model=self.model,
            content=[
                {
                    'type': 'text',
                    'text': prompt.strip()
                }
            ],
            extra_body={
                'resolution': resolution,
                'ratio': ratio,
                'duration': duration,
            }
        )
        task_id = create_result.id

        while True:
            get_result = self.client.content_generation.tasks.get(task_id=task_id)
            status = get_result.status
            if status == "succeeded":
                return get_result.content.video_url
            elif status == "failed":
                raise Exception(str(get_result.error))
            else:
                time.sleep(3)



import re
from typing import Tuple
from pathlib import Path
from io import BytesIO

import requests
from PIL import Image, ImageEnhance


def download(url: str, output: str):
    output = Path(output)
    if output.exists():
        raise FileExistsError(f'Path {output} already exists.')

    try:
        headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/120.0.0.0 Safari/537.36'}
        response = requests.get(url, headers=headers, timeout=30)
        response.raise_for_status()
    except Exception as e:
        raise requests.RequestException(f'Error: {e}')

    output.write_bytes(response.content)


def get_image_info(image: str) -> str:
    try:
        img = _load_image(image)
    except Exception as e:
        raise ValueError(f'Error loading image: {e}')

    info = {
        'format': str(img.format),
        'size': f"{img.width}x{img.height}",
        'mode': img.mode,
        'file_size': _format_file_size(len(img.tobytes()))
    }
    return info


def crop_image(image: str, box: str, output: str):
    try:
        x1, y1, x2, y2 = map(float, box.split(','))
    except Exception:
        raise ValueError('box must be "x1, y1, x2, y2" integers')

    img = _load_image(image)

    width = img.width
    height = img.height

    x1 = width * x1
    y1 = height * y1
    x2 = width * x2
    y2 = height * y2
    x1 = int(max(0, x1))
    y1 = int(max(0, y1))
    x2 = int(max(0, x2))
    y2 = int(max(0, y2))

    cropped = img.crop((x1, y1, x2, y2))
    _save_image(cropped, output)


def resize_image(image: str, size: str, output: str, keep_aspect: bool = True):
    m = re.match(r'^(\d+)x(\d+)$', size)
    if not m:
        raise ValueError('size must be WIDTHxHEIGHT, e.g., "1024x768"')

    w, h = map(int, m.groups())

    img = _load_image(image)
    if keep_aspect:
        resized = img.copy()
        resized.thumbnail((w, h), Image.Resampling.LANCZOS)
    else:
        resized = img.resize((w, h), Image.Resampling.LANCZOS)

    _save_image(resized, output)


def convert_image(image: str, format: str, output: str, quality: int = 90):
    fmt = format.upper()
    if fmt not in ('PNG', 'JPEG', 'JPG', 'WEBP'):
        raise ValueError('format must be one of PNG/JPEG/JPG/WEBP')

    img = _load_image(image)
    _save_image(img, output, format_hint=fmt, quality=quality)


def adjust_image(image: str, output: str, brightness: float = 1.0, contrast: float = 1.0, saturation: float = 1.0):
    img = _load_image(image)
    img = ImageEnhance.Brightness(img).enhance(brightness)
    img = ImageEnhance.Contrast(img).enhance(contrast)
    img = ImageEnhance.Color(img).enhance(saturation)

    _save_image(img, output)


def paste_image(front_image: str, backgroud_image: str, position: Tuple[int, int], output: str):
    front_img = _load_image(front_image)
    back_img = _load_image(backgroud_image)

    back_img.paste(front_img, tuple(position))
    _save_image(back_img, output)


def _load_image(image: str) -> Image.Image:
    if re.match(r'^https?://', image):
        try:
            resp = requests.get(image, timeout=30)
            resp.raise_for_status()
        except Exception as e:
            raise requests.RequestException(f'Error: {e}')
        return Image.open(BytesIO(resp.content)).convert('RGBA')

    path = Path(image)
    if not path.exists():
        raise FileNotFoundError(f'Image not found: {image}')
    return Image.open(path)


def _save_image(img: Image.Image, output: str, format_hint: str | None = None, quality: int = 90) -> None:
    out = Path(output)
    if out.exists():
        raise FileExistsError(f'Path {out} already exists.')
    out.parent.mkdir(parents=True, exist_ok=True)

    fmt = format_hint or (out.suffix[1:].upper() if out.suffix else 'PNG')
    
    if fmt.upper() == 'JPG':
        fmt = 'JPEG'
    
    save_kwargs = {}

    if fmt.upper() in ('JPEG', 'WEBP'):
        save_kwargs['quality'] = quality

    if fmt.upper() == 'JPEG':
        img = img.convert('RGB')

    img.save(out, format=fmt, **save_kwargs)


def _format_file_size(size_bytes: int) -> str:
    if size_bytes < 1024:
        return f"{size_bytes} B"
    elif size_bytes < 1024 * 1024:
        return f"{size_bytes / 1024:.1f} KB"
    elif size_bytes < 1024 * 1024 * 1024:
        return f"{size_bytes / (1024 * 1024):.1f} MB"
    else:
        return f"{size_bytes / (1024 * 1024 * 1024):.1f} GB"



import base64
from pathlib import Path
from typing import List, Dict
from volcenginesdkarkruntime import Ark

from imagenx.predictor.base.base_image_to_image import BaseImageToImage


class DoubaoImageToImage(BaseImageToImage):

    def __init__(self, model: str, api_key: str):
        self.model = model
        self.client = Ark(
            base_url='https://ark.cn-beijing.volces.com/api/v3',
            api_key=api_key,
        )

    def image_to_image(self, prompt: str, images: List[str], size: str = '2048x2048') -> List[Dict[str, str]]:
        '''根据输入的提示词和图片生成图片。

        Args:
            prompt (str): 生成图片的提示词
            images (List[str]): 输入图片url列表或文件路径列表
            size (str): 生成图像的分辨率或宽高像素值
                    分辨率可选值：'1K'、'2K', '4K'
                    宽高像素可选值：2048x2048、2304x1728、1728x2304、2560x1440、1440x2560、2496x1664、1664x2496、3024x1296
        
        Returns:
            List[Dict[str: str]]: 图片url列表。
        '''
        if len(images) == 0:
            pass_images = None
        else:
            pass_images = []

        for i in images:
            if str(i).startswith('http'):
                pass_images.append(i)
            else:
                pass_images.append(self._image_to_base64(i))

        response = self.client.images.generate(
            model=self.model,
            prompt=prompt,
            sequential_image_generation='auto',
            response_format='url',
            image=pass_images,
            size=size,
            stream=False,
            watermark=False
        )

        result = []
        for item in response.model_dump()['data']:
            if 'b64_json' in item:
                item.pop('b64_json')
            result.append(item)

        return result

    def _image_to_base64(self, image_path: str) -> str:
        image_path = Path(image_path)

        with open(image_path, 'rb') as image_file:
            base64_image = base64.b64encode(image_file.read()).decode('utf-8')
            base64_image = f'data:image/{image_path.suffix.strip(".")};base64,{base64_image}'

        return base64_image